"""Say hello function usage example."""
from helloworld import say_hello

# Generate "Hello world!"
greeting = say_hello()
print(greeting)

# Generate "Hello mkmenta!"
greeting = say_hello("mkmenta")
print(greeting)
